==> koffice-2.1.2.tar.xz: koffice-2.1.2/karbon/plugins/filtereffects/OffsetEffect.h <==
/* This file is part of the KDE project
 * Copyright (c) 2009 Jan Hambrecht <jaham@gmx.net>
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef OFFSETEFFECT_H
#define OFFSETEFFECT_H

#include "KoFilterEffect.h"
#include <QtCore/QPointF>

#define OffsetEffectId "feOffset"

/// An image offset effect
class OffsetEffect : public KoFilterEffect
{
public:
    OffsetEffect();
    
    QPointF offset() const;
    void setOffset(const QPointF &offset);
    
    /// reimplemented from KoFilterEffect
    virtual QImage processImage(const QImage &image, const KoFilterEffectRenderContext &context) const;
    /// reimplemented from KoFilterEffect
    virtual bool load(const KoXmlElement &element, const QMatrix &matrix);
    /// reimplemented from KoFilterEffect
    virtual void save(KoXmlWriter &writer);
    
private:
    QPointF m_offset;
};

#endif // OFFSETEFFECT_H

==> koffice-2.3.3.tar.xz: koffice-2.3.3/karbon/plugins/filtereffects/OffsetEffect.h <==
/* This file is part of the KDE project
 * Copyright (c) 2009 Jan Hambrecht <jaham@gmx.net>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef OFFSETEFFECT_H
#define OFFSETEFFECT_H

#include "KoFilterEffect.h"
#include <QtCore/QPointF>

#define OffsetEffectId "feOffset"

/// An image offset effect
class OffsetEffect : public KoFilterEffect
{
public:
    OffsetEffect();

    QPointF offset() const;
    void setOffset(const QPointF &offset);

    /// reimplemented from KoFilterEffect
    virtual QImage processImage(const QImage &image, const KoFilterEffectRenderContext &context) const;
    /// reimplemented from KoFilterEffect
    virtual bool load(const KoXmlElement &element, const KoFilterEffectLoadingContext &context);
    /// reimplemented from KoFilterEffect
    virtual void save(KoXmlWriter &writer);

private:
    QPointF m_offset;
};

#endif // OFFSETEFFECT_H
